@@ -102,8 +102,7 @@ sub get_data {
 # "You don’t like your job, you don’t strike.
 #  You go in every day and do it really half-assed. That’s the American way."
 sub help {
-  my $self = shift;
-  print $self->usage;
+  print shift->usage;
   exit 0;
 }
 
@@ -209,6 +208,9 @@ L<Mojo::Command> implements the following attributes.
 
 Currently active application, defaults to a L<Mojo::HelloWorld> object.
 
+  # Introspect
+  say "Template path: $_" for @{$command->app->renderer->paths};
+
 =head2 C<description>
 
   my $description = $command->description;
@@ -334,7 +336,7 @@ relative file.
   $command->run;
   $command->run(@ARGV);
 
-Run command.
+Run command, meant to be overloaded in a subclass.
 
 =head2 C<write_file>
 
