@@ -21,7 +21,7 @@ sub run {
 
   # Request body
   my $len = $env->{CONTENT_LENGTH};
-  while (!$req->is_finished) {
+  until ($req->is_finished) {
     my $chunk = ($len && $len < CHUNK_SIZE) ? $len : CHUNK_SIZE;
     my $read = $env->{'psgi.input'}->read(my $buffer, $chunk, 0);
     last unless $read;
