@@ -1,10 +1,9 @@
 package Mojolicious::Commands;
-use Mojo::Base 'Mojo::Base';
+use Mojo::Base 'Mojo::Command';
 
 use Getopt::Long
   qw/GetOptions :config no_auto_abbrev no_ignore_case pass_through/;
 use Mojo::Loader;
-use Mojo::Server;
 
 # "One day a man has everything, the next day he blows up a $400 billion
 #  space station, and the next day he has nothing. It makes you think."
@@ -56,7 +55,7 @@ sub run {
   my ($self, $name, @args) = @_;
 
   # Application loader
-  return Mojo::Server->new->app if defined $ENV{MOJO_APP_LOADER};
+  return $self->app if defined $ENV{MOJO_APP_LOADER};
 
   # Try to detect environment
   $name = $self->detect($name) unless $ENV{MOJO_NO_DETECT};
@@ -287,7 +286,8 @@ for debugging.
 
 =head1 ATTRIBUTES
 
-L<Mojolicious::Commands> implements the following attributes.
+L<Mojolicious::Commands> inherits all attributes from L<Mojo::Command> and
+implements the following new ones.
 
 =head2 C<hint>
 
@@ -313,7 +313,7 @@ C<Mojolicious::Command> and C<Mojo::Command>.
 
 =head1 METHODS
 
-L<Mojolicious::Commands> inherits all methods from L<Mojo::Base> and
+L<Mojolicious::Commands> inherits all methods from L<Mojo::Command> and
 implements the following new ones.
 
 =head2 C<detect>
